@@ -17,6 +17,10 @@ _level_dict = {
     DEBUG: "DEBUG",
 }
 
+
+_nameToLevel = {v: k for k, v in _level_dict.items()}
+
+
 def addLevelName(level, name):
     _level_dict[level] = name
 
@@ -143,9 +147,10 @@ class StreamHandler(Handler):
 
     def emit(self, record):
         self._stream.write(self.formatter.format(record) + self.terminator)
+        self.flush()
 
     def flush(self):
-        pass
+        self._stream.flush()
 
 
 class FileHandler(StreamHandler):
